@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef FAKESESSION_H
-#define FAKESESSION_H
+#pragma once
 
 #include "akonaditestfake_export.h"
 #include "collection.h"
@@ -17,7 +16,10 @@ class AKONADITESTFAKE_EXPORT FakeSession : public Session
 {
     Q_OBJECT
 public:
-    enum Mode { EndJobsImmediately, EndJobsManually };
+    enum Mode {
+        EndJobsImmediately,
+        EndJobsManually,
+    };
 
     explicit FakeSession(const QByteArray &sessionId = QByteArray(), Mode mode = EndJobsImmediately, QObject *parent = nullptr);
 
@@ -32,4 +34,3 @@ Q_SIGNALS:
     friend class FakeSessionPrivate;
 };
 
-#endif
