@@ -7,16 +7,14 @@
 #include "firstrun_p.h"
 
 #include <KAboutData>
-#include <QCommandLineParser>
 #include <QApplication>
+#include <QCommandLineParser>
 
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
-    KAboutData aboutData(QStringLiteral("akonadi-firstrun"),
-                         QStringLiteral("Test akonadi-firstrun"),
-                         QStringLiteral("0.10"));
+    KAboutData aboutData(QStringLiteral("akonadi-firstrun"), QStringLiteral("Test akonadi-firstrun"), QStringLiteral("0.10"));
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
@@ -24,7 +22,7 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    Akonadi::Firstrun *f = new Akonadi::Firstrun();
+    auto f = new Akonadi::Firstrun();
     QObject::connect(f, &Akonadi::Firstrun::destroyed, &app, &QApplication::quit);
     app.exec();
 }
