@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INSPECTABLECHANGERECORDER_H
-#define INSPECTABLECHANGERECORDER_H
+#pragma once
 
 #include "changerecorder.h"
 #include "changerecorder_p.h"
@@ -65,10 +64,14 @@ private Q_SLOTS:
 
 private:
     struct MessageStruct {
-        enum Position { Queued, FilterPipelined, Pipelined, Emitted };
+        enum Position {
+            Queued,
+            FilterPipelined,
+            Pipelined,
+            Emitted,
+        };
         Position position;
     };
     QQueue<MessageStruct> m_messages;
 };
 
-#endif
