@@ -4,15 +4,23 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MODELSPY_H
-#define MODELSPY_H
+#pragma once
 
 #include "akonaditestfake_export.h"
 #include <QModelIndex>
 #include <QObject>
 #include <QVariantList>
 
-enum SignalType { NoSignal, RowsAboutToBeInserted, RowsInserted, RowsAboutToBeRemoved, RowsRemoved, RowsAboutToBeMoved, RowsMoved, DataChanged };
+enum SignalType {
+    NoSignal,
+    RowsAboutToBeInserted,
+    RowsInserted,
+    RowsAboutToBeRemoved,
+    RowsRemoved,
+    RowsAboutToBeMoved,
+    RowsMoved,
+    DataChanged,
+};
 
 struct ExpectedSignal {
     ExpectedSignal(SignalType type, int start, int end, const QVariantList &newData)
@@ -113,4 +121,3 @@ inline uint qHash(const QVariantList &list)
 }
 #endif
 
-#endif
