@@ -24,6 +24,9 @@
 #include <QFile>
 #include <QSettings>
 #include <QTimer>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 bool SetupTest::startAkonadiDaemon()
 {
@@ -37,7 +40,7 @@ bool SetupTest::startAkonadiDaemon()
     mAkonadiDaemonProcess->setProgram(Akonadi::StandardDirs::findExecutable(QStringLiteral("akonadi_control")), {QStringLiteral("--instance"), instanceId()});
     mAkonadiDaemonProcess->start();
     const bool started = mAkonadiDaemonProcess->waitForStarted(5000);
-    qCInfo(AKONADITEST_LOG) << "Started akonadi daemon with pid:" << mAkonadiDaemonProcess->pid();
+    qCInfo(AKONADITEST_LOG) << "Started akonadi daemon with pid:" << mAkonadiDaemonProcess->processId();
     return started;
 }
 
@@ -66,7 +69,7 @@ void SetupTest::setupAgents()
     for (const auto &[instance, sync] : agents) {
         qCDebug(AKONADITEST_LOG) << "Creating agent" << instance << "...";
         ++mSetupJobCount;
-        Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(instance, this);
+        auto job = new Akonadi::AgentInstanceCreateJob(instance, this);
         job->setProperty("sync", sync);
         connect(job, &Akonadi::AgentInstanceCreateJob::result, this, &SetupTest::agentCreationResult);
         job->start();
@@ -89,7 +92,7 @@ void SetupTest::agentCreationResult(KJob *job)
         if (needsSync) {
             ++mSetupJobCount;
             qCDebug(AKONADITEST_LOG) << "Scheduling Agent sync of" << instance.identifier();
-            Akonadi::ResourceSynchronizationJob *sync = new Akonadi::ResourceSynchronizationJob(instance, this);
+            auto sync = new Akonadi::ResourceSynchronizationJob(instance, this);
             connect(sync, &Akonadi::ResourceSynchronizationJob::result, this, &SetupTest::synchronizationResult);
             sync->start();
         }
@@ -323,7 +326,7 @@ void SetupTest::shutdown()
         qCInfo(AKONADITEST_LOG) << "Shutting down Akonadi control...";
         Akonadi::ServerManager::self()->stop();
         // safety timeout
-        QTimer::singleShot(30 * 1000, this, &SetupTest::shutdownHarder);
+        QTimer::singleShot(30s, this, &SetupTest::shutdownHarder);
         break;
     case Akonadi::ServerManager::NotRunning:
     case Akonadi::ServerManager::Broken:
@@ -331,7 +334,7 @@ void SetupTest::shutdown()
         break;
     case Akonadi::ServerManager::Stopping:
         // safety timeout
-        QTimer::singleShot(30 * 1000, this, &SetupTest::shutdownHarder);
+        QTimer::singleShot(30s, this, &SetupTest::shutdownHarder);
         break;
     }
 }
