@@ -45,29 +45,29 @@ public:
 
     bool hasTable(const QString &tableName) override
     {
-        Q_UNUSED(tableName);
+        Q_UNUSED(tableName)
         return m_hasTable;
     }
     bool hasIndex(const QString &tableName, const QString &indexName) override
     {
-        Q_UNUSED(tableName);
-        Q_UNUSED(indexName);
+        Q_UNUSED(tableName)
+        Q_UNUSED(indexName)
         return m_hasIndex;
     }
     bool hasColumn(const QString &tableName, const QString &columnName) override
     {
-        Q_UNUSED(tableName);
-        Q_UNUSED(columnName);
+        Q_UNUSED(tableName)
+        Q_UNUSED(columnName)
         return false;
     }
     bool isTableEmpty(const QString &tableName) override
     {
-        Q_UNUSED(tableName);
+        Q_UNUSED(tableName)
         return m_tableEmpty;
     }
-    QVector< ForeignKey > foreignKeyConstraints(const QString &tableName) override
+    QVector<ForeignKey> foreignKeyConstraints(const QString &tableName) override
     {
-        Q_UNUSED(tableName);
+        Q_UNUSED(tableName)
         return m_foreignKeys;
     }
 
@@ -87,14 +87,17 @@ void DbInitializerTest::testRun_data()
     QTest::addColumn<QString>("driverName");
     QTest::addColumn<QString>("filename");
     QTest::addColumn<bool>("hasTable");
-    QTest::addColumn<QVector<DbIntrospector::ForeignKey> >("fks");
+    QTest::addColumn<QVector<DbIntrospector::ForeignKey>>("fks");
     QTest::addColumn<bool>("hasFks");
 
     QVector<DbIntrospector::ForeignKey> fks;
 
-    QTest::newRow("mysql") << "QMYSQL" << ":dbinit_mysql" << false << fks << true;
-    QTest::newRow("sqlite") << "QSQLITE" << ":dbinit_sqlite" << false << fks << true;
-    QTest::newRow("psql") << "QPSQL" << ":dbinit_psql" << false << fks << true;
+    QTest::newRow("mysql") << "QMYSQL"
+                           << ":dbinit_mysql" << false << fks << true;
+    QTest::newRow("sqlite") << "QSQLITE"
+                            << ":dbinit_sqlite" << false << fks << true;
+    QTest::newRow("psql") << "QPSQL"
+                          << ":dbinit_psql" << false << fks << true;
 
     DbIntrospector::ForeignKey fk;
     fk.name = QL1S("myForeignKeyIdentifier");
@@ -105,9 +108,12 @@ void DbInitializerTest::testRun_data()
     fk.onDelete = QL1S("CASCADE");
     fks.push_back(fk);
 
-    QTest::newRow("mysql (incremental)") << "QMYSQL" << ":dbinit_mysql_incremental" << true << fks << true;
-    QTest::newRow("sqlite (incremental)") << "QSQLITE" << ":dbinit_sqlite_incremental" << true << fks << true;
-    QTest::newRow("psql (incremental)") << "QPSQL" << ":dbinit_psql_incremental" << true << fks << true;
+    QTest::newRow("mysql (incremental)") << "QMYSQL"
+                                         << ":dbinit_mysql_incremental" << true << fks << true;
+    QTest::newRow("sqlite (incremental)") << "QSQLITE"
+                                          << ":dbinit_sqlite_incremental" << true << fks << true;
+    QTest::newRow("psql (incremental)") << "QPSQL"
+                                        << ":dbinit_psql_incremental" << true << fks << true;
 }
 
 void DbInitializerTest::testRun()
@@ -129,7 +135,7 @@ void DbInitializerTest::testRun()
 
         StatementCollector collector;
         initializer->setTestInterface(&collector);
-        DbFakeIntrospector *introspector = new DbFakeIntrospector(db);
+        auto introspector = new DbFakeIntrospector(db);
         introspector->m_hasTable = hasTable;
         introspector->m_hasIndex = hasTable;
         introspector->m_tableEmpty = !hasTable;
@@ -140,7 +146,7 @@ void DbInitializerTest::testRun()
         QVERIFY(initializer->updateIndexesAndConstraints());
         QVERIFY(!collector.statements.isEmpty());
 
-        Q_FOREACH (const QString &statement, collector.statements) {
+        for (const QString &statement : std::as_const(collector.statements)) {
             const QString expected = readNextStatement(&file).simplified();
 
             QString normalized = statement.simplified();
