@@ -13,15 +13,14 @@
 
 using namespace AkRanges;
 
-namespace {
-
+namespace
+{
 int transformFreeFunc(int i)
 {
     return i * 2;
 }
 
-struct TransformHelper
-{
+struct TransformHelper {
 public:
     static int transform(int i)
     {
@@ -39,8 +38,7 @@ bool filterFreeFunc(int i)
     return i % 2 == 0;
 }
 
-struct FilterHelper
-{
+struct FilterHelper {
 public:
     static bool filter(int i)
     {
@@ -82,24 +80,16 @@ private Q_SLOTS:
     void testContainerConversion()
     {
         {
-            QVector<int> in = { 1, 2, 3, 4, 5 };
+            QVector<int> in = {1, 2, 3, 4, 5};
             QCOMPARE(in | Actions::toQList, in.toList());
             QCOMPARE(in | Actions::toQList | Actions::toQVector, in);
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-            QCOMPARE(in | Actions::toQSet, in.toList().toSet()); // clazy:exclude=container-anti-pattern
-#else
             QCOMPARE(in | Actions::toQSet, QSet<int>(in.begin(), in.end()));
-#endif
         }
         {
-            QList<int> in = { 1, 2, 3, 4, 5 };
+            QList<int> in = {1, 2, 3, 4, 5};
             QCOMPARE(in | Actions::toQVector, in.toVector());
             QCOMPARE(in | Actions::toQVector | Actions::toQList, in);
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-            QCOMPARE(in | Actions::toQSet, in.toSet());
-#else
             QCOMPARE(in | Actions::toQSet, QSet<int>(in.begin(), in.end()));
-#endif
         }
     }
 
@@ -113,13 +103,13 @@ private Q_SLOTS:
     void testRangeConversion()
     {
         {
-            QList<int> in = { 1, 2, 3, 4, 5 };
+            QList<int> in = {1, 2, 3, 4, 5};
             AkRanges::detail::Range<QList<int>::const_iterator> range(in.cbegin(), in.cend());
             QCOMPARE(range | Actions::toQVector, QVector<int>::fromList(in));
         }
 
         {
-            QVector<int> in = { 1, 2, 3, 4, 5 };
+            QVector<int> in = {1, 2, 3, 4, 5};
             AkRanges::detail::Range<QVector<int>::const_iterator> range(in.cbegin(), in.cend());
             QCOMPARE(range | Actions::toQList, in.toList());
         }
@@ -134,23 +124,30 @@ private Q_SLOTS:
 
     void testTransform()
     {
-        QList<int> in = { 1, 2, 3, 4, 5 };
-        QList<int> out = { 2, 4, 6, 8, 10 };
-        QCOMPARE(in | Views::transform([](int i) { return i * 2; }) | Actions::toQList, out);
+        QList<int> in = {1, 2, 3, 4, 5};
+        QList<int> out = {2, 4, 6, 8, 10};
+        QCOMPARE(in | Views::transform([](int i) {
+                     return i * 2;
+                 }) | Actions::toQList,
+                 out);
         QCOMPARE(in | Views::transform(transformFreeFunc) | Actions::toQList, out);
         QCOMPARE(in | Views::transform(&TransformHelper::transform) | Actions::toQList, out);
         QCOMPARE(in | Views::transform(TransformHelper()) | Actions::toQList, out);
     }
 
 private:
-    class CopyCounter {
+    class CopyCounter
+    {
     public:
         CopyCounter() = default;
         CopyCounter(const CopyCounter &other)
-            : copyCount(other.copyCount + 1), transformed(other.transformed)
-        {}
+            : copyCount(other.copyCount + 1)
+            , transformed(other.transformed)
+        {
+        }
         CopyCounter(CopyCounter &&other) = default;
-        CopyCounter &operator=(const CopyCounter &other) {
+        CopyCounter &operator=(const CopyCounter &other)
+        {
             copyCount = other.copyCount + 1;
             transformed = other.transformed;
             return *this;
@@ -167,13 +164,13 @@ private Q_SLOTS:
     void testTransformCopyCount()
     {
         {
-            QList<CopyCounter> in = { {} }; // 1st copy (QList::append())
-            QList<CopyCounter> out = in
-                | Views::transform([](const auto &c) {
-                        CopyCounter r(c);   // 2nd copy (expected)
-                        r.transformed = true;
-                        return r; })
-                | Actions::toQList;         // 3rd copy (QList::append())
+            QList<CopyCounter> in = {{}}; // 1st copy (QList::append())
+            QList<CopyCounter> out = in | Views::transform([](const auto &c) {
+                                         CopyCounter r(c); // 2nd copy (expected)
+                                         r.transformed = true;
+                                         return r;
+                                     })
+                | Actions::toQList; // 3rd copy (QList::append())
             QCOMPARE(out.size(), in.size());
             QCOMPARE(out[0].copyCount, 3);
             QCOMPARE(out[0].transformed, true);
@@ -182,11 +179,11 @@ private Q_SLOTS:
         {
             QVector<CopyCounter> in(1); // construct vector of one element, so no copying
                                         // occurs at initialization
-            QVector<CopyCounter> out = in
-                | Views::transform([](const auto &c) {
-                        CopyCounter r(c);   // 1st copy
-                        r.transformed = true;
-                        return r; })
+            QVector<CopyCounter> out = in | Views::transform([](const auto &c) {
+                                           CopyCounter r(c); // 1st copy
+                                           r.transformed = true;
+                                           return r;
+                                       })
                 | Actions::toQVector;
             QCOMPARE(out.size(), in.size());
             QCOMPARE(out[0].copyCount, 1);
@@ -197,23 +194,29 @@ private Q_SLOTS:
     void testTransformConvert()
     {
         {
-            QList<int> in = { 1, 2, 3, 4, 5 };
-            QVector<int> out = { 2, 4, 6, 8, 10 };
-            QCOMPARE(in | Views::transform([](int i) { return i * 2; }) | Actions::toQVector, out);
+            QList<int> in = {1, 2, 3, 4, 5};
+            QVector<int> out = {2, 4, 6, 8, 10};
+            QCOMPARE(in | Views::transform([](int i) {
+                         return i * 2;
+                     }) | Actions::toQVector,
+                     out);
         }
 
         {
-            QVector<int> in = { 1, 2, 3, 4, 5 };
-            QList<int> out = { 2, 4, 6, 8, 10 };
-            QCOMPARE(in | Views::transform([](int i) { return i * 2; }) | Actions::toQList, out);
+            QVector<int> in = {1, 2, 3, 4, 5};
+            QList<int> out = {2, 4, 6, 8, 10};
+            QCOMPARE(in | Views::transform([](int i) {
+                         return i * 2;
+                     }) | Actions::toQList,
+                     out);
         }
     }
 
     void testCreateRange()
     {
         {
-            QList<int> in = { 1, 2, 3, 4, 5, 6 };
-            QList<int> out = { 3, 4, 5 };
+            QList<int> in = {1, 2, 3, 4, 5, 6};
+            QList<int> out = {3, 4, 5};
             QCOMPARE(Views::range(in.begin() + 2, in.begin() + 5) | Actions::toQList, out);
         }
     }
@@ -221,11 +224,11 @@ private Q_SLOTS:
     void testRangeWithTransform()
     {
         {
-            QList<int> in = { 1, 2, 3, 4, 5, 6 };
-            QList<int> out = { 6, 8, 10 };
-            QCOMPARE(Views::range(in.begin() + 2, in.begin() + 5)
-                        | Views::transform([](int i) { return i  * 2; })
-                        | Actions::toQList,
+            QList<int> in = {1, 2, 3, 4, 5, 6};
+            QList<int> out = {6, 8, 10};
+            QCOMPARE(Views::range(in.begin() + 2, in.begin() + 5) | Views::transform([](int i) {
+                         return i * 2;
+                     }) | Actions::toQList,
                      out);
         }
     }
@@ -233,19 +236,23 @@ private Q_SLOTS:
     void testTransformType()
     {
         {
-            QStringList in = { QStringLiteral("foo"), QStringLiteral("foobar"), QStringLiteral("foob") };
-            QList<int> out = { 3, 6, 4 };
-            QCOMPARE(in | Views::transform([](const auto &str) { return str.size(); }) | Actions::toQList, out);
+            QStringList in = {QStringLiteral("foo"), QStringLiteral("foobar"), QStringLiteral("foob")};
+            QList<int> out = {3, 6, 4};
+            QCOMPARE(in | Views::transform([](const auto &str) {
+                         return str.size();
+                     }) | Actions::toQList,
+                     out);
         }
     }
 
     void testFilter()
     {
         {
-            QList<int> in = { 1, 2, 3, 4, 5, 6, 7, 8 };
-            QList<int> out = { 2, 4, 6, 8 };
-            QCOMPARE(in | Views::filter([](int i) { return i % 2 == 0; })
-                        | Actions::toQList,
+            QList<int> in = {1, 2, 3, 4, 5, 6, 7, 8};
+            QList<int> out = {2, 4, 6, 8};
+            QCOMPARE(in | Views::filter([](int i) {
+                         return i % 2 == 0;
+                     }) | Actions::toQList,
                      out);
             QCOMPARE(in | Views::filter(filterFreeFunc) | Actions::toQList, out);
             QCOMPARE(in | Views::filter(&FilterHelper::filter) | Actions::toQList, out);
@@ -256,22 +263,23 @@ private Q_SLOTS:
     void testFilterTransform()
     {
         {
-            QStringList in = { QStringLiteral("foo"), QStringLiteral("foobar"), QStringLiteral("foob") };
-            QList<int> out = { 6 };
-            QCOMPARE(in | Views::transform(&QString::size)
-                        | Views::filter([](int i) { return i > 5; })
-                        | Actions::toQList,
+            QStringList in = {QStringLiteral("foo"), QStringLiteral("foobar"), QStringLiteral("foob")};
+            QList<int> out = {6};
+            QCOMPARE(in | Views::transform(&QString::size) | Views::filter([](int i) {
+                         return i > 5;
+                     }) | Actions::toQList,
                      out);
-            QCOMPARE(in | Views::filter([](const auto &str) { return str.size() > 5; })
-                        | Views::transform(&QString::size)
-                        | Actions::toQList,
+            QCOMPARE(in | Views::filter([](const auto &str) {
+                         return str.size() > 5;
+                     }) | Views::transform(&QString::size)
+                         | Actions::toQList,
                      out);
         }
     }
 
     void testTemporaryContainer()
     {
-        const auto func = []{
+        const auto func = [] {
             QStringList rv;
             for (int i = 0; i < 5; i++) {
                 rv.push_back(QString::number(i));
@@ -279,54 +287,66 @@ private Q_SLOTS:
             return rv;
         };
         {
-            QList<int> out = { 0, 2, 4 };
-            QCOMPARE(func() | Views::transform([](const auto &str) { return str.toInt(); })
-                            | Views::filter([](int i) { return i % 2 == 0; })
-                            | Actions::toQList,
+            QList<int> out = {0, 2, 4};
+            QCOMPARE(func() | Views::transform([](const auto &str) {
+                         return str.toInt();
+                     }) | Views::filter([](int i) {
+                         return i % 2 == 0;
+                     }) | Actions::toQList,
                      out);
         }
         {
-            QList<int> out = { 0, 2, 4 };
-            QCOMPARE(func() | Views::filter([](const auto &v) { return v.toInt() % 2 == 0; })
-                            | Views::transform([](const auto &str) { return str.toInt(); })
-                            | Actions::toQList,
+            QList<int> out = {0, 2, 4};
+            QCOMPARE(func() | Views::filter([](const auto &v) {
+                         return v.toInt() % 2 == 0;
+                     }) | Views::transform([](const auto &str) {
+                         return str.toInt();
+                     }) | Actions::toQList,
                      out);
         }
     }
 
     void testTemporaryRange()
     {
-        const auto func = []{
+        const auto func = [] {
             QStringList rv;
             for (int i = 0; i < 5; ++i) {
                 rv.push_back(QString::number(i));
             }
-            return rv | Views::transform([](const auto &str) { return str.toInt(); });
+            return rv | Views::transform([](const auto &str) {
+                       return str.toInt();
+                   });
         };
-        QList<int> out = { 1, 3 };
-        QCOMPARE(func() | Views::filter([](int i) { return i % 2 == 1; })
-                        | Actions::toQList,
+        QList<int> out = {1, 3};
+        QCOMPARE(func() | Views::filter([](int i) {
+                     return i % 2 == 1;
+                 }) | Actions::toQList,
                  out);
     }
 
 private:
-    struct ForEachCallable
-    {
+    struct ForEachCallable {
     public:
         explicit ForEachCallable(QList<int> &out)
-            : mOut(out) {}
+            : mOut(out)
+        {
+        }
 
-        void operator()(int i) {
+        void operator()(int i)
+        {
             mOut.push_back(i);
         }
 
-        static void append(int i) {
+        static void append(int i)
+        {
             sOut.push_back(i);
         }
-        static void clear() {
+        static void clear()
+        {
             sOut.clear();
         }
         static QList<int> sOut;
+
     private:
         QList<int> &mOut;
     };
@@ -334,10 +354,12 @@ private:
 private Q_SLOTS:
     void testForEach()
     {
-        const QList<int> in = { 1, 2, 3, 4, 5, 6 };
+        const QList<int> in = {1, 2, 3, 4, 5, 6};
         {
             QList<int> out;
-            in | Actions::forEach([&out](int v) { out.push_back(v); });
+            in | Actions::forEach([&out](int v) {
+                out.push_back(v);
+            });
             QCOMPARE(out, in);
         }
         {
@@ -352,32 +374,29 @@ private Q_SLOTS:
         }
         {
             QList<int> out;
-            QCOMPARE(in | Actions::forEach([&out](int v) { out.push_back(v); })
-                        | Views::filter([](int v){ return v % 2 == 0; })
-                        | Views::transform([](int v) { return v * 2; })
-                        | Actions::toQList,
-                     QList<int>({ 4, 8, 12 }));
+            QCOMPARE(in | Actions::forEach([&out](int v) {
+                         out.push_back(v);
+                     }) | Views::filter([](int v) {
+                         return v % 2 == 0;
+                     }) | Views::transform([](int v) {
+                         return v * 2;
+                     }) | Actions::toQList,
+                     QList<int>({4, 8, 12}));
             QCOMPARE(out, in);
         }
-
     }
 
 private:
-    template<template<typename, typename> class Container>
-    void testKeysValuesHelper()
+    template<template<typename, typename> class Container> void testKeysValuesHelper()
     {
-        const Container<int, QString> in = {
-            { 1, QStringLiteral("1") },
-            { 2, QStringLiteral("2") },
-            { 3, QStringLiteral("3") }
-        };
+        const Container<int, QString> in = {{1, QStringLiteral("1")}, {2, QStringLiteral("2")}, {3, QStringLiteral("3")}};
 
         {
-            const QList<int> out = { 1, 2, 3 };
+            const QList<int> out = {1, 2, 3};
             QCOMPARE(out, in | Views::keys | Actions::toQList);
         }
         {
-            const QStringList out = { QStringLiteral("1"), QStringLiteral("2"), QStringLiteral("3") };
+            const QStringList out = {QStringLiteral("1"), QStringLiteral("2"), QStringLiteral("3")};
             QCOMPARE(out, in | Views::values | Actions::toQList);
         }
     }
@@ -391,23 +410,41 @@ private Q_SLOTS:
 
     void testAll()
     {
-        const QList<int> vals = { 2, 4, 6, 8, 10 };
-        QVERIFY(vals | Actions::all([](int v) { return v % 2 == 0; }));
-        QVERIFY(!(vals | Actions::all([](int v) { return v % 2 == 1; })));
+        const QList<int> vals = {2, 4, 6, 8, 10};
+        QVERIFY(vals | Actions::all([](int v) {
+                    return v % 2 == 0;
+                }));
+        QVERIFY(!(vals | Actions::all([](int v) {
+                      return v % 2 == 1;
+                  })));
     }
 
     void testAny()
     {
-        const QList<int> vals = { 1, 3, 5, 7, 9 };
-        QVERIFY(vals | Actions::any([](int v) { return v % 2 == 1; }));
-        QVERIFY(!(vals | Actions::any([](int v) { return v % 2 == 0; })));
+        const QList<int> vals = {1, 3, 5, 7, 9};
+        QVERIFY(vals | Actions::any([](int v) {
+                    return v % 2 == 1;
+                }));
+        QVERIFY(!(vals | Actions::any([](int v) {
+                      return v % 2 == 0;
+                  })));
     }
 
     void testNone()
     {
-        const QList<int> vals = { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 };
-        QVERIFY(vals | Views::filter([](int i) { return i % 2 == 0; }) | Actions::none([](int i) { return i % 2 == 1; }));
-        QVERIFY(!(vals | Views::filter([](int i) { return i % 2 == 0; }) | Actions::none([](int i) { return i % 2 == 0; })));
+        const QList<int> vals = {1, 2, 3, 4, 5, 6, 7, 8, 9, 10};
+        QVERIFY(vals | Views::filter([](int i) {
+                    return i % 2 == 0;
+                })
+                | Actions::none([](int i) {
+                      return i % 2 == 1;
+                  }));
+        QVERIFY(!(vals | Views::filter([](int i) {
+                      return i % 2 == 0;
+                  })
+                  | Actions::none([](int i) {
+                        return i % 2 == 0;
+                    })));
     }
 };
 
