@@ -25,7 +25,7 @@
 #include <QTest>
 
 #include <memory>
-
+using namespace std::chrono_literals;
 using namespace Akonadi;
 
 /***
@@ -92,9 +92,9 @@ class TagEditWidgetTest : public QObject
 
         bool checkSelectionIsEmpty() const
         {
-            auto *const model = tagsView->model();
-            for (int i = 0; i < model->rowCount(); ++i) {
-                if (model->data(model->index(i, 0), Qt::CheckStateRole).value<Qt::CheckState>() != Qt::Unchecked) {
+            auto *const tagViewModel = tagsView->model();
+            for (int i = 0; i < tagViewModel->rowCount(); ++i) {
+                if (tagViewModel->data(tagViewModel->index(i, 0), Qt::CheckStateRole).value<Qt::CheckState>() != Qt::Unchecked) {
                     return false;
                 }
             }
@@ -125,13 +125,13 @@ class TagEditWidgetTest : public QObject
             // Clicking the button blocks (QDialog::exec), so we need to confirm the
             // dialog from event loop
             bool confirmed = false;
-            QTimer::singleShot(100, [this, confirmDeletion, &confirmed]() {
+            QTimer::singleShot(100ms, [this, confirmDeletion, &confirmed]() {
                 confirmed = confirmDialog(confirmDeletion);
                 QVERIFY(confirmed);
             });
             QTest::mouseClick(tagDeleteButton, Qt::LeftButton);
 
-            // Check that the confirmation was succesful
+            // Check that the confirmation was successful
             AKVERIFY(confirmed);
 
             return true;
@@ -293,7 +293,7 @@ private Q_SLOTS:
             QTest::keyClick(test.tagsView, Qt::Key_Space);
         }
 
-        // Confirm that the selection occured
+        // Confirm that the selection occurred
         for (int i = 0; i < model->rowCount(); ++i) {
             const auto expectedState = i % 2 == 0 ? Qt::Checked : Qt::Unchecked;
             QCOMPARE(model->data(model->index(i, 0), Qt::CheckStateRole).value<Qt::CheckState>(), expectedState);
