@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef PREPROCESSORBASE_P_H
-#define PREPROCESSORBASE_P_H
+#pragma once
 
 #include "agentbase_p.h"
 
@@ -43,4 +42,3 @@ public:
 
 }
 
-#endif
