@@ -4,14 +4,16 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_TRANSPORTRESOURCEBASE_H
-#define AKONADI_TRANSPORTRESOURCEBASE_H
+#pragma once
 
 #include "akonadiagentbase_export.h"
-#include "item.h"
+// AkonadiCore
+#include <akonadi/item.h>
 
 #include <QString>
 
+#include <memory>
+
 namespace Akonadi
 {
 class TransportResourceBasePrivate;
@@ -81,10 +83,9 @@ public:
 
 private:
     /// @cond PRIVATE
-    TransportResourceBasePrivate *const d;
+    std::unique_ptr<TransportResourceBasePrivate> const d;
     /// @endcond
 };
 
 }
 
-#endif
