@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
 
-#ifndef SESSION_H
-#define SESSION_H
+#pragma once
 
 #include <QElapsedTimer>
 #include <QLocalSocket>
@@ -20,7 +19,7 @@ class Session : public QObject
     Q_OBJECT
 public:
     explicit Session(const QString &input, QObject *parent = nullptr);
-    ~Session();
+    ~Session() override;
 
     void printStats() const;
 
@@ -46,4 +45,3 @@ private:
     qint64 m_sentBytes = 0;
 };
 
-#endif // SESSION_H
