@@ -10,8 +10,12 @@
 
 #include "akonadicore_export.h"
 
+#include <memory>
+
 namespace Akonadi
 {
+class AgentConfigurationManagerPrivate;
+
 class AKONADICORE_EXPORT AgentConfigurationManager : public QObject
 {
     Q_OBJECT
@@ -29,9 +33,8 @@ public:
 private:
     AgentConfigurationManager(QObject *parent = nullptr);
 
-    class Private;
-    friend class Private;
-    QScopedPointer<Private> const d;
+    friend class AgentConfigurationManagerPrivate;
+    std::unique_ptr<AgentConfigurationManagerPrivate> const d;
     static AgentConfigurationManager *sInstance;
 };
 
