@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_AGENTMANAGER_P_H
-#define AKONADI_AGENTMANAGER_P_H
+#pragma once
 
 #include "agentmanagerinterface.h"
 
@@ -95,4 +94,3 @@ public:
 
 }
 
-#endif
