@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CHANGEMEDIATOR_P_H
-#define AKONADI_CHANGEMEDIATOR_P_H
+#pragma once
 
 #include <QList>
 #include <QObject>
@@ -42,4 +41,3 @@ protected:
 
 }
 
-#endif
