@@ -4,26 +4,25 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "changenotificationdependenciesfactory_p.h"
-#include "sessionthread_p.h"
-#include "connection_p.h"
-#include "changemediator_p.h"
-#include "servermanager.h"
 #include "akonadicore_debug.h"
+#include "changemediator_p.h"
+#include "changenotificationdependenciesfactory_p.h"
+#include "connection_p.h"
+#include "servermanager.h"
 #include "session_p.h"
+#include "sessionthread_p.h"
 
 #include <qdbusextratypes.h>
 
 using namespace Akonadi;
 
-Connection *ChangeNotificationDependenciesFactory::createNotificationConnection(Session *session,
-                                                                                CommandBuffer *commandBuffer)
+Connection *ChangeNotificationDependenciesFactory::createNotificationConnection(Session *session, CommandBuffer *commandBuffer)
 {
     if (!Akonadi::ServerManager::self()->isRunning()) {
         return nullptr;
     }
 
-    auto *connection = new Connection(Connection::NotificationConnection, session->sessionId(), commandBuffer);
+    auto connection = new Connection(Connection::NotificationConnection, session->sessionId(), commandBuffer);
     addConnection(session, connection);
     return connection;
 }
@@ -40,7 +39,7 @@ void ChangeNotificationDependenciesFactory::destroyNotificationConnection(Sessio
 
 QObject *ChangeNotificationDependenciesFactory::createChangeMediator(QObject *parent)
 {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     return ChangeMediator::instance();
 }
 
