@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CHANGERECORDER_H
-#define AKONADI_CHANGERECORDER_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "monitor.h"
@@ -45,7 +44,7 @@ public:
      * Destroys the change recorder.
      * All not yet processed changes are written back to the config file.
      */
-    ~ChangeRecorder();
+    ~ChangeRecorder() override;
 
     /**
      * Sets the QSettings object used for persistent recorded changes.
@@ -108,4 +107,3 @@ private:
 
 }
 
-#endif
