@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CHANGERECORDER_P_H
-#define AKONADI_CHANGERECORDER_P_H
+#pragma once
 
 #include "akonadiprivate_export.h"
 #include "changerecorder.h"
@@ -52,4 +51,3 @@ private:
 
 } // namespace Akonadi
 
-#endif
