@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CHANGERECORDERJOURNAL_P_H
-#define CHANGERECORDERJOURNAL_P_H
+#pragma once
 
 #include "akonaditests_export.h"
 #include "private/protocol_p.h"
@@ -19,7 +18,13 @@ namespace Akonadi
 class AKONADI_TESTS_EXPORT ChangeRecorderJournalReader
 {
 public:
-    enum LegacyType { InvalidType, Item, Collection, Tag, Relation };
+    enum LegacyType {
+        InvalidType,
+        Item,
+        Collection,
+        Tag,
+        Relation,
+    };
 
     // Ancient QSettings legacy store
     static Protocol::ChangeNotificationPtr loadQSettingsNotification(QSettings *settings);
@@ -27,7 +32,20 @@ public:
     static QQueue<Protocol::ChangeNotificationPtr> loadFrom(QFile *device, bool &needsFullSave);
 
 private:
-    enum LegacyOp { InvalidOp, Add, Modify, Move, Remove, Link, Unlink, Subscribe, Unsubscribe, ModifyFlags, ModifyTags, ModifyRelations };
+    enum LegacyOp {
+        InvalidOp,
+        Add,
+        Modify,
+        Move,
+        Remove,
+        Link,
+        Unlink,
+        Subscribe,
+        Unsubscribe,
+        ModifyFlags,
+        ModifyTags,
+        ModifyRelations,
+    };
 
     static Protocol::ChangeNotificationPtr loadQSettingsItemNotification(QSettings *settings);
     static Protocol::ChangeNotificationPtr loadQSettingsCollectionNotification(QSettings *settings);
@@ -64,4 +82,3 @@ private:
 
 } // namespace
 
-#endif
