@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_FIRSTRUN_P_H
-#define AKONADI_FIRSTRUN_P_H
+#pragma once
 
 #include <QObject>
 #include <QStringList>
@@ -55,7 +54,7 @@ class Firstrun : public QObject
     Q_OBJECT
 public:
     explicit Firstrun(QObject *parent = nullptr);
-    ~Firstrun();
+    ~Firstrun() override;
 
 private:
     void findPendingDefaults();
@@ -73,4 +72,3 @@ private:
 
 }
 
-#endif
