@@ -5,8 +5,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEM_SERIALIZER_P_H
-#define AKONADI_ITEM_SERIALIZER_P_H
+#pragma once
 
 #include <QByteArray>
 #include <QSet>
@@ -30,7 +29,11 @@ class Item;
 class AKONADI_TESTS_EXPORT ItemSerializer
 {
 public:
-    enum PayloadStorage { Internal, External, Foreign };
+    enum PayloadStorage {
+        Internal,
+        External,
+        Foreign,
+    };
 
     /** throws ItemSerializerException on failure */
     static void deserialize(Item &item, const QByteArray &label, const QByteArray &data, int version, PayloadStorage storage);
@@ -123,4 +126,3 @@ public:
 
 }
 
-#endif
