@@ -47,9 +47,6 @@ public:
         , mBatchSize(10)
         , mMergeMode(Akonadi::ItemSync::RIDMerge)
     {
-        // we want to fetch all data by default
-        mFetchScope.fetchFullPayload();
-        mFetchScope.fetchAllAttributes();
     }
 
     void createOrMerge(const Item &item);
@@ -77,9 +74,6 @@ public:
     TransactionSequence *mCurrentTransaction = nullptr;
     int mTransactionJobs;
 
-    // fetch scope for initial item listing
-    ItemFetchScope mFetchScope;
-
     Akonadi::Item::List mRemoteItemQueue;
     Akonadi::Item::List mRemovedRemoteItemQueue;
     Akonadi::Item::List mCurrentBatchRemoteItems;
@@ -262,18 +256,6 @@ void ItemSync::setIncrementalSyncItems(const Item::List &changedItems, const Ite
     d->execute();
 }
 
-void ItemSync::setFetchScope(ItemFetchScope &fetchScope)
-{
-    Q_D(ItemSync);
-    d->mFetchScope = fetchScope;
-}
-
-ItemFetchScope &ItemSync::fetchScope()
-{
-    Q_D(ItemSync);
-    return d->mFetchScope;
-}
-
 void ItemSync::doStart()
 {
 }
@@ -393,7 +375,7 @@ void ItemSyncPrivate::processBatch()
 void ItemSyncPrivate::processItems()
 {
     // added / updated
-    for (const Item &remoteItem : qAsConst(mCurrentBatchRemoteItems)) {
+    for (const Item &remoteItem : std::as_const(mCurrentBatchRemoteItems)) {
         if (remoteItem.remoteId().isEmpty()) {
             qCWarning(AKONADICORE_LOG) << "Item " << remoteItem.id() << " does not have a remote identifier";
             continue;
