@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONMODIFYJOB_H
-#define AKONADI_COLLECTIONMODIFYJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job.h"
@@ -104,4 +103,3 @@ private:
 
 }
 
-#endif
