@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONMOVEJOB_H
-#define AKONADI_COLLECTIONMOVEJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job.h"
@@ -57,4 +56,3 @@ private:
 
 }
 
-#endif
