@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONSTATISTICSJOB_H
-#define AKONADI_COLLECTIONSTATISTICSJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job.h"
@@ -88,4 +87,3 @@ private:
 
 }
 
-#endif
