@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_INVALIDATECACHEJOB_P_H
-#define AKONADI_INVALIDATECACHEJOB_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job.h"
@@ -37,4 +36,3 @@ private:
 
 }
 
-#endif // AKONADI_INVALIDATECACHEJOB_P_H
