@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEMDELETEJOB_H
-#define AKONADI_ITEMDELETEJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "item.h"
@@ -134,4 +133,3 @@ private:
 
 }
 
-#endif
