@@ -1,11 +1,10 @@
 /*
-    Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006-2007 Volker Krause <vkrause@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEMFETCHJOB_H
-#define AKONADI_ITEMFETCHJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "item.h"
@@ -13,7 +12,6 @@
 
 namespace Akonadi
 {
-
 class Collection;
 class ItemFetchJobPrivate;
 class ItemFetchScope;
@@ -201,9 +199,9 @@ public:
     void setCollection(const Collection &collection);
 
     enum DeliveryOption {
-        ItemGetter = 0x1,            ///< items available through items()
+        ItemGetter = 0x1, ///< items available through items()
         EmitItemsIndividually = 0x2, ///< emitted via signal upon reception
-        EmitItemsInBatches = 0x4,    ///< emitted via signal in bulk (collected and emitted delayed via timer)
+        EmitItemsInBatches = 0x4, ///< emitted via signal in bulk (collected and emitted delayed via timer)
         Default = ItemGetter | EmitItemsInBatches
     };
     Q_DECLARE_FLAGS(DeliveryOptions, DeliveryOption)
@@ -227,6 +225,18 @@ public:
      */
     int count() const;
 
+    /**
+     * Sets the limit of fetched items.
+     *
+     * @param limit the maximum number of items to retrieve.
+     * The default value for @p limit is -1, indicating no limit.
+     * @param start specifies the offset of the first item to retrieve.
+     * @param order specifies whether items will be fetched
+     * starting with the highest or lowest ID of the item.
+     */
+
+    void setLimit(int limit, int start, Qt::SortOrder order = Qt::DescendingOrder);
+
 Q_SIGNALS:
     /**
      * This signal is emitted whenever new items have been fetched completely.
@@ -251,4 +261,3 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Akonadi::ItemFetchJob::DeliveryOptions)
 
-#endif
