@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEMMODIFYJOB_H
-#define AKONADI_ITEMMODIFYJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "item.h"
@@ -195,4 +194,3 @@ private:
 
 }
 
-#endif
