@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEMMODIFYJOB_P_H
-#define AKONADI_ITEMMODIFYJOB_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job_p.h"
@@ -26,7 +25,12 @@ using ModifyItemsCommandPtr = QSharedPointer<ModifyItemsCommand>;
 class AKONADICORE_EXPORT ItemModifyJobPrivate : public JobPrivate
 {
 public:
-    enum Operation { RemoteId, RemoteRevision, Gid, Dirty };
+    enum Operation {
+        RemoteId,
+        RemoteRevision,
+        Gid,
+        Dirty,
+    };
 
     explicit ItemModifyJobPrivate(ItemModifyJob *parent);
 
@@ -59,4 +63,3 @@ public:
 
 }
 
-#endif
