@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_KJOBPRIVATEBASE_P_H
-#define AKONADI_KJOBPRIVATEBASE_P_H
+#pragma once
 
 #include <QObject>
 
@@ -36,4 +35,3 @@ private Q_SLOTS:
 
 }
 
-#endif
