@@ -4,16 +4,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_LINKJOB_H
-#define AKONADI_LINKJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
-#include "job.h"
 #include "item.h"
+#include "job.h"
 
 namespace Akonadi
 {
-
 class Collection;
 class LinkJobPrivate;
 
@@ -76,9 +74,8 @@ protected:
 
 private:
     Q_DECLARE_PRIVATE(LinkJob)
-    template <typename T> friend class LinkJobImpl;
+    template<typename T> friend class LinkJobImpl;
 };
 
 }
 
-#endif
