@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_RESOURCESELECTJOB_P_H
-#define AKONADI_RESOURCESELECTJOB_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job.h"
@@ -91,4 +90,3 @@ private:
 
 }
 
-#endif
