@@ -4,16 +4,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SEARCHCREATEJOB_H
-#define AKONADI_SEARCHCREATEJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
-#include "job.h"
 #include "collection.h"
+#include "job.h"
 
 namespace Akonadi
 {
-
 class Collection;
 class SearchQuery;
 class SearchCreateJobPrivate;
@@ -173,4 +171,3 @@ private:
 
 }
 
-#endif
