@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SEARCHRESULTJOB_P_H
-#define AKONADI_SEARCHRESULTJOB_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job.h"
@@ -39,4 +38,3 @@ private:
 };
 }
 
-#endif // AKONADI_SEARCHRESULTJOB_H
