@@ -4,14 +4,15 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SPECIALCOLLECTIONSDISCOVERYJOB_H
-#define AKONADI_SPECIALCOLLECTIONSDISCOVERYJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "collection.h"
 #include "specialcollections.h"
 #include <KCompositeJob>
 
+#include <memory>
+
 namespace Akonadi
 {
 class SpecialCollectionsDiscoveryJobPrivate;
@@ -53,10 +54,9 @@ protected:
 
 private:
     /// @cond PRIVATE
-    SpecialCollectionsDiscoveryJobPrivate *const d;
+    std::unique_ptr<SpecialCollectionsDiscoveryJobPrivate> const d;
     /// @endcond
 };
 
 } // namespace Akonadi
 
-#endif // AKONADI_SPECIALCOLLECTIONSDISCOVERYJOB_H
