@@ -13,10 +13,14 @@
 
 #include <QVariant>
 
+#include <memory>
+
 namespace Akonadi
 {
 // ===================== ResourceScanJob ============================
 
+class ResourceScanJobPrivate;
+
 /**
   @internal
   Helper job for SpecialCollectionsRequestJob.
@@ -70,9 +74,8 @@ protected:
     void doStart() override;
 
 private:
-    class Private;
-    friend class Private;
-    Private *const d;
+    friend class ResourceScanJobPrivate;
+    std::unique_ptr<ResourceScanJobPrivate> const d;
 };
 
 // ===================== DefaultResourceJob ============================
@@ -146,10 +149,11 @@ protected:
 
 private:
     friend class DefaultResourceJobPrivate;
-    DefaultResourceJobPrivate *const d;
+    std::unique_ptr<DefaultResourceJobPrivate> const d;
 };
 
 // ===================== GetLockJob ============================
+class GetLockJobPrivate;
 
 /**
   @internal
@@ -188,9 +192,8 @@ public:
     void start() override;
 
 private:
-    class Private;
-    friend class Private;
-    Private *const d;
+    friend class GetLockJobPrivate;
+    std::unique_ptr<GetLockJobPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void doStart())
 };
