@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SUBSCRIPTIONJOB_P_H
-#define AKONADI_SUBSCRIPTIONJOB_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "collection.h"
@@ -60,4 +59,3 @@ private:
 
 }
 
-#endif
