@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_TAGDELETEJOB_H
-#define AKONADI_TAGDELETEJOB_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "job.h"
@@ -43,4 +42,3 @@ private:
 
 }
 
-#endif
