@@ -5,14 +5,14 @@
 */
 
 #include "tagfetchjob.h"
+#include "attributefactory.h"
 #include "job_p.h"
 #include "protocolhelper_p.h"
 #include "tagfetchscope.h"
-#include "attributefactory.h"
 #include <QTimer>
 
 using namespace Akonadi;
-
+using namespace std::chrono_literals;
 class Akonadi::TagFetchJobPrivate : public JobPrivate
 {
 public:
@@ -26,11 +26,14 @@ public:
         Q_Q(TagFetchJob);
         mEmitTimer = new QTimer(q);
         mEmitTimer->setSingleShot(true);
-        mEmitTimer->setInterval(100);
-        q->connect(mEmitTimer, &QTimer::timeout, q, [this]() { timeout(); });
+        mEmitTimer->setInterval(100ms);
+        q->connect(mEmitTimer, &QTimer::timeout, q, [this]() {
+            timeout();
+        });
     }
 
-    void aboutToFinish() override {
+    void aboutToFinish() override
+    {
         timeout();
     }
 
@@ -153,3 +156,6 @@ Tag::List TagFetchJob::tags() const
 }
 
 #include "moc_tagfetchjob.cpp"
+#include <chrono>
+
+using namespace std::chrono_literals;
