@@ -17,10 +17,10 @@ using namespace Akonadi;
 /**
  * @internal
  */
-class Q_DECL_HIDDEN CollectionFilterProxyModel::Private
+class Akonadi::CollectionFilterProxyModelPrivate
 {
 public:
-    explicit Private(CollectionFilterProxyModel *parent)
+    explicit CollectionFilterProxyModelPrivate(CollectionFilterProxyModel *parent)
         : mParent(parent)
     {
         mimeChecker.addWantedMimeType(QStringLiteral("text/uri-list"));
@@ -34,7 +34,7 @@ public:
     bool mExcludeVirtualCollections = false;
 };
 
-bool CollectionFilterProxyModel::Private::collectionAccepted(const QModelIndex &index, bool checkResourceVisibility)
+bool CollectionFilterProxyModelPrivate::collectionAccepted(const QModelIndex &index, bool checkResourceVisibility)
 {
     // Retrieve supported mimetypes
     const auto collection = mParent->sourceModel()->data(index, EntityTreeModel::CollectionRole).value<Collection>();
@@ -62,7 +62,7 @@ bool CollectionFilterProxyModel::Private::collectionAccepted(const QModelIndex &
                 qCDebug(AKONADICORE_LOG) << "We got a new collection:" << mParent->sourceModel()->data(index).toString()
                                          << "but the resource is not visible:" << mParent->sourceModel()->data(resource).toString();
                 acceptedResources.clear();
-                // defer reset, the model might still be supplying new items at this point which crashs
+                // defer reset, the model might still be supplying new items at this point which crashes
                 mParent->invalidateFilter();
                 return true;
             }
@@ -96,14 +96,11 @@ bool CollectionFilterProxyModel::Private::collectionAccepted(const QModelIndex &
 
 CollectionFilterProxyModel::CollectionFilterProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
-    , d(new Private(this))
+    , d(new CollectionFilterProxyModelPrivate(this))
 {
 }
 
-CollectionFilterProxyModel::~CollectionFilterProxyModel()
-{
-    delete d;
-}
+CollectionFilterProxyModel::~CollectionFilterProxyModel() = default;
 
 void CollectionFilterProxyModel::addMimeTypeFilters(const QStringList &typeList)
 {
