@@ -4,10 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ENTITYTREEMODELPRIVATE_H
-#define ENTITYTREEMODELPRIVATE_H
+#pragma once
 
-#include <KJob>
+class KJob;
 
 #include "collectionfetchjob.h"
 #include "item.h"
@@ -30,7 +29,10 @@ class AgentInstance;
 
 struct Node {
     using Id = qint64;
-    enum Type : char { Item, Collection };
+    enum Type : char {
+        Item,
+        Collection,
+    };
 
     explicit Node(Type type, Id id, Akonadi::Collection::Id parentId)
         : id(id)
@@ -167,7 +169,10 @@ public:
     ~EntityTreeModelPrivate();
     EntityTreeModel *const q_ptr;
 
-    enum RetrieveDepth { Base, Recursive };
+    enum RetrieveDepth {
+        Base,
+        Recursive,
+    };
 
     void init(Monitor *monitor);
 
@@ -389,4 +394,3 @@ public:
 
 }
 
-#endif
