@@ -18,7 +18,7 @@ namespace Akonadi
 class RecursiveCollectionFilterProxyModelPrivate
 {
     Q_DECLARE_PUBLIC(RecursiveCollectionFilterProxyModel)
-    RecursiveCollectionFilterProxyModel *q_ptr;
+    RecursiveCollectionFilterProxyModel *const q_ptr;
 
 public:
     explicit RecursiveCollectionFilterProxyModelPrivate(RecursiveCollectionFilterProxyModel *model)
@@ -42,10 +42,7 @@ RecursiveCollectionFilterProxyModel::RecursiveCollectionFilterProxyModel(QObject
     setRecursiveFilteringEnabled(true);
 }
 
-RecursiveCollectionFilterProxyModel::~RecursiveCollectionFilterProxyModel()
-{
-    delete d_ptr;
-}
+RecursiveCollectionFilterProxyModel::~RecursiveCollectionFilterProxyModel() = default;
 
 bool RecursiveCollectionFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
 {
