@@ -10,7 +10,7 @@
 
 using namespace Akonadi;
 
-class TrashFilterProxyModel::TrashFilterProxyModelPrivate
+class Akonadi::TrashFilterProxyModelPrivate
 {
 public:
     TrashFilterProxyModelPrivate()
@@ -26,10 +26,7 @@ TrashFilterProxyModel::TrashFilterProxyModel(QObject *parent)
     setRecursiveFilteringEnabled(true);
 }
 
-TrashFilterProxyModel::~TrashFilterProxyModel()
-{
-    delete d_ptr;
-}
+TrashFilterProxyModel::~TrashFilterProxyModel() = default;
 
 void TrashFilterProxyModel::showTrash(bool enable)
 {
