@@ -40,11 +40,8 @@ MonitorPrivate::MonitorPrivate(ChangeNotificationDependenciesFactory *dependenci
     , mFetchChangedOnly(false)
     , session(Session::defaultSession())
     , collectionCache(nullptr)
-    , itemCache(nullptr)
-    , tagCache(nullptr)
     , mCommandBuffer(parent, "handleCommands")
     , pendingModificationChanges(Protocol::ModifySubscriptionCommand::None)
-    , pendingModificationTimer(nullptr)
     , monitorReady(false)
     , fetchCollection(false)
     , fetchCollectionStatistics(false)
@@ -555,7 +552,8 @@ bool MonitorPrivate::emitNotification(const Protocol::ChangeNotificationPtr &msg
         subscriber.setMonitoredItems(subNtf.items());
         subscriber.setMonitoredTags(subNtf.tags());
         QSet<Monitor::Type> monitorTypes;
-        Q_FOREACH (auto type, subNtf.types()) {
+        const auto types = subNtf.types();
+        for (auto type : types) {
             if (type == Protocol::ModifySubscriptionCommand::NoType) {
                 continue;
             }
@@ -1116,9 +1114,9 @@ bool MonitorPrivate::emitCollectionNotification(const Protocol::CollectionChange
     case Protocol::CollectionChangeNotification::Add:
         return emitToListeners(&Monitor::collectionAdded, collection, parent);
     case Protocol::CollectionChangeNotification::Modify:
-        handled |= emitToListeners(QOverload<const Akonadi::Collection &>::of(&Monitor::collectionChanged), collection);
+        handled |= emitToListeners(qOverload<const Akonadi::Collection &>(&Monitor::collectionChanged), collection);
         handled |=
-            emitToListeners(QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Monitor::collectionChanged), collection, msg.changedParts());
+            emitToListeners(qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Monitor::collectionChanged), collection, msg.changedParts());
         return handled;
     case Protocol::CollectionChangeNotification::Move:
         return emitToListeners(&Monitor::collectionMoved, collection, parent, destination);
@@ -1369,8 +1367,8 @@ void MonitorPrivate::updateListeners(QMetaMethod signal, ListenerAction action)
     UPDATE_LISTENERS(&Monitor::itemsUnlinked)
     UPDATE_LISTENERS(&Monitor::collectionAdded)
 
-    UPDATE_LISTENERS(QOverload<const Akonadi::Collection &>::of(&Monitor::collectionChanged))
-    UPDATE_LISTENERS((QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Monitor::collectionChanged)))
+    UPDATE_LISTENERS(qOverload<const Akonadi::Collection &>(&Monitor::collectionChanged))
+    UPDATE_LISTENERS((qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Monitor::collectionChanged)))
     UPDATE_LISTENERS(&Monitor::collectionMoved)
     UPDATE_LISTENERS(&Monitor::collectionRemoved)
     UPDATE_LISTENERS(&Monitor::collectionSubscribed)
