@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef NOTIFICATIONSOURCE_P_H
-#define NOTIFICATIONSOURCE_P_H
+#pragma once
 
 #include <QObject>
 
@@ -25,7 +24,7 @@ class AKONADI_TESTS_EXPORT NotificationSource : public QObject
 
 public:
     explicit NotificationSource(QObject *source);
-    ~NotificationSource();
+    ~NotificationSource() override;
 
     QString identifier() const;
 
@@ -45,4 +44,3 @@ public:
 
 }
 
-#endif // NOTIFICATIONSOURCE_P_H
