@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_PASTEHELPER_P_H
-#define AKONADI_PASTEHELPER_P_H
+#pragma once
 
 #include "akonadicore_export.h"
 #include "collection.h"
@@ -20,7 +19,7 @@ class Session;
 /**
   @internal
 
-  Helper methods for pasting/droping content into a collection.
+  Helper methods for pasting/dropping content into a collection.
 
   @todo Use in item/collection models as well for dnd
 */
@@ -55,4 +54,3 @@ AKONADICORE_EXPORT KJob *pasteUriList(const QMimeData *mimeData, const Collectio
 
 }
 
-#endif
