@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_PLUGINLOADER_P_H
-#define AKONADI_PLUGINLOADER_P_H
+#pragma once
 
 #include "akonaditests_export.h"
 
@@ -56,4 +55,3 @@ private:
 
 }
 
-#endif
