@@ -12,6 +12,8 @@
 
 namespace Akonadi
 {
+class TagFetchScopePrivate;
+
 /**
  * @short Specifies which parts of a tag should be fetched from the Akonadi storage.
  *
@@ -103,7 +105,7 @@ public:
     void setFetchIdOnly(bool fetchIdOnly);
 
     /**
-     * Sets whether only the id of the tags should be retieved or the complete tag.
+     * Sets whether only the id of the tags should be retrieved or the complete tag.
      *
      * @see tagFetchScope()
      * @since 4.15
@@ -111,9 +113,8 @@ public:
     bool fetchIdOnly() const;
 
 private:
-    struct Private;
     /// @cond PRIVATE
-    QSharedPointer<Private> d;
+    QSharedPointer<TagFetchScopePrivate> d;
     /// @endcond
 };
 
