@@ -1,24 +1,10 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_IMAPSET_P_H
-#define AKONADI_IMAPSET_P_H
+#pragma once
 
 #include "akonadiprivate_export.h"
 
@@ -38,6 +24,7 @@ class DataStream;
 
 namespace Akonadi
 {
+class ImapIntervalPrivate;
 
 /**
   Represents a single interval in an ImapSet.
@@ -49,12 +36,12 @@ public:
     /**
      * Describes the ids stored in the interval.
      */
-    typedef qint64 Id;
+    using Id = qint64;
 
     /**
       A list of ImapInterval objects.
     */
-    typedef QList<ImapInterval> List;
+    using List = QList<ImapInterval>;
 
     /**
       Constructs an interval that covers all positive numbers.
@@ -132,13 +119,14 @@ public:
     QByteArray toImapSequence() const;
 
 private:
-    class Private;
-    QSharedDataPointer<Private> d;
+    QSharedDataPointer<ImapIntervalPrivate> d;
 
     friend Protocol::DataStream &operator<<(Protocol::DataStream &stream, const Akonadi::ImapInterval &interval);
     friend Protocol::DataStream &operator>>(Protocol::DataStream &stream, Akonadi::ImapInterval &interval);
 };
 
+class ImapSetPrivate;
+
 /**
   Represents a set of natural numbers (1->\f$\infty\f$) in a as compact as possible form.
   Used to address Akonadi items via the IMAP protocol or in the database.
@@ -150,20 +138,20 @@ public:
     /**
      * Describes the ids stored in the set.
      */
-    typedef qint64 Id;
+    using Id = qint64;
 
     /**
       Constructs an empty set.
     */
     ImapSet();
 
-    ImapSet(qint64 Id);                     // krazy:exclude=explicit
+    ImapSet(qint64 Id); // krazy:exclude=explicit
 
-    ImapSet(const QVector<qint64> &ids);    // krazy:exclude=explicit
+    ImapSet(const QVector<qint64> &ids); // krazy:exclude=explicit
 
-    ImapSet(const QList<qint64> &ids);      // krazy:exclude=explicit
+    ImapSet(const QList<qint64> &ids); // krazy:exclude=explicit
 
-    ImapSet(const ImapInterval &interval);  // krazy:exclude=explicit
+    ImapSet(const ImapInterval &interval); // krazy:exclude=explicit
 
     /**
       Copy constructor.
@@ -223,8 +211,7 @@ public:
     bool isEmpty() const;
 
 private:
-    class Private;
-    QSharedDataPointer<Private> d;
+    QSharedDataPointer<ImapSetPrivate> d;
 
     friend Protocol::DataStream &operator<<(Protocol::DataStream &stream, const Akonadi::ImapSet &set);
     friend Protocol::DataStream &operator>>(Protocol::DataStream &stream, Akonadi::ImapSet &set);
@@ -242,4 +229,3 @@ Q_DECLARE_METATYPE(Akonadi::ImapInterval)
 Q_DECLARE_METATYPE(Akonadi::ImapInterval::List)
 Q_DECLARE_METATYPE(Akonadi::ImapSet)
 
-#endif
