@@ -32,8 +32,6 @@
         return reinterpret_cast<const Class##Private *>(d_ptr.constData());                                                                                    \
     }
 
-#define COMPARE(prop) ((prop) == ((decltype(this))other)->prop)
-
 namespace Akonadi
 {
 namespace Protocol
@@ -505,7 +503,7 @@ void ItemFetchScope::toJson(QJsonObject &json) const
     json[QStringLiteral("AncestorDepth")] = static_cast<std::underlying_type<AncestorDepth>::type>(mAncestorDepth);
 
     QJsonArray requestedPartsArray;
-    for (const auto &part : qAsConst(mRequestedParts)) {
+    for (const auto &part : std::as_const(mRequestedParts)) {
         requestedPartsArray.append(QString::fromUtf8(part));
     }
     json[QStringLiteral("RequestedParts")] = requestedPartsArray;
@@ -719,7 +717,7 @@ bool ChangeNotification::isMove() const
 
 bool ChangeNotification::appendAndCompress(ChangeNotificationList &list, const ChangeNotificationPtr &msg)
 {
-    // It is likely that compressable notifications are within the last few notifications, so avoid searching a list that is potentially huge
+    // It is likely that compressible notifications are within the last few notifications, so avoid searching a list that is potentially huge
     static const int maxCompressionSearchLength = 10;
     int searchCounter = 0;
     // There are often multiple Collection Modify notifications in the queue,
@@ -771,7 +769,7 @@ void ChangeNotification::toJson(QJsonObject &json) const
     json[QStringLiteral("session")] = QString::fromUtf8(mSessionId);
 
     QJsonArray metadata;
-    for (const auto &m : qAsConst(mMetaData)) {
+    for (const auto &m : std::as_const(mMetaData)) {
         metadata.append(QString::fromUtf8(m));
     }
     json[QStringLiteral("metadata")] = metadata;
