@@ -4,10 +4,9 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-//krazy:excludeall=dpointer,inline
+// krazy:excludeall=dpointer,inline
 
-#ifndef AKONADI_PROTOCOLEXCEPTION_P_H
-#define AKONADI_PROTOCOLEXCEPTION_P_H
+#pragma once
 
 #include "akonadiprivate_export.h"
 
@@ -18,7 +17,6 @@
 
 namespace Akonadi
 {
-
 class AKONADIPRIVATE_EXPORT ProtocolException : public std::exception
 {
 public:
@@ -32,7 +30,8 @@ public:
     ProtocolException(const ProtocolException &) = delete;
     ProtocolException &operator=(const ProtocolException &) = delete;
 
-    const char *what() const throw() override {
+    const char *what() const throw() override
+    {
         return mWhat.constData();
     }
 
@@ -41,4 +40,3 @@ private:
 };
 } // namespace Akonadi
 
-#endif
