@@ -90,16 +90,12 @@ public:
         QString mVariableName() const
         {
             return QStringLiteral("m") + name[0].toUpper() +
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 2)
                 QStringView(name).mid(1);
-#else
-                name.midRef(1);
-#endif
         }
     };
 
     CtorNode(const QVector<Argument> &args, ClassNode *parent);
-    ~CtorNode();
+    ~CtorNode() override;
 
     QVector<Argument> arguments() const;
     void setArgumentType(const QString &name, const QString &type);
@@ -154,7 +150,7 @@ public:
     };
 
     PropertyNode(const QString &name, const QString &type, ClassNode *parent);
-    ~PropertyNode();
+    ~PropertyNode() override;
 
     QString type() const;
     QString name() const;
