@@ -640,12 +640,13 @@ void QSQLiteDriver::close()
     Q_D(QSQLiteDriver);
 
     if (isOpen()) {
-        Q_FOREACH (QSQLiteResult *result, d->results) {
+        for (QSQLiteResult *result : std::as_const(d->results)) {
             result->d_func()->finalize();
         }
 
-        if (sqlite3_close(d->access) != SQLITE_OK)
+        if (sqlite3_close(d->access) != SQLITE_OK) {
             setLastError(qMakeError(d->access, tr("Error closing database"), QSqlError::ConnectionError));
+        }
         d->access = nullptr;
         setOpen(false);
         setOpenError(false);
