@@ -35,7 +35,7 @@ QSQLiteDriverPlugin::QSQLiteDriverPlugin()
 QSqlDriver *QSQLiteDriverPlugin::create(const QString &name)
 {
     if (name == QLatin1String("QSQLITE3")) {
-        QSQLiteDriver *driver = new QSQLiteDriver();
+        auto driver = new QSQLiteDriver();
         return driver;
     }
     return nullptr;
