@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
 
-#ifndef BRIDGECONNECTION_H
-#define BRIDGECONNECTION_H
+#pragma once
 
 #include <QObject>
 
@@ -18,7 +17,7 @@ class BridgeConnection : public QObject
 
 public:
     explicit BridgeConnection(QTcpSocket *remoteSocket, QObject *parent = nullptr);
-    ~BridgeConnection();
+    ~BridgeConnection() override;
 
 protected Q_SLOTS:
     virtual void connectLocal() = 0;
@@ -56,4 +55,3 @@ protected:
     void connectLocal() override;
 };
 
-#endif // BRIDGECONNECTION_H
