@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_DEBUGINTERFACE_H
-#define AKONADI_DEBUGINTERFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -37,4 +36,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
