@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_EXCEPTION_H
-#define AKONADI_EXCEPTION_H
+#pragma once
 
 #include <QByteArray>
 #include <QString>
@@ -21,17 +20,17 @@ namespace Server
 class Exception : public std::exception
 {
 public:
-    explicit Exception(const char *what) throw()
+    explicit Exception(const char *what) noexcept
         : mWhat(what)
     {
     }
 
-    explicit Exception(const QByteArray &what) throw()
+    explicit Exception(const QByteArray &what) noexcept
         : mWhat(what)
     {
     }
 
-    explicit Exception(const QString &what) throw()
+    explicit Exception(const QString &what) noexcept
         : mWhat(what.toUtf8())
     {
     }
@@ -39,14 +38,14 @@ public:
     Exception(const Exception &) = delete;
     Exception &operator=(const Exception &) = delete;
 
-    ~Exception() throw() override = default;
+    ~Exception() override = default;
 
-    const char *what() const throw() override
+    const char *what() const noexcept override
     {
         return mWhat.constData();
     }
 
-    virtual const char *type() const throw()
+    virtual const char *type() const noexcept
     {
         return "General Exception";
     }
@@ -59,19 +58,19 @@ protected:
     class classname : public Akonadi::Server::Exception                                                                                                        \
     {                                                                                                                                                          \
     public:                                                                                                                                                    \
-        classname(const char *what) throw()                                                                                                                    \
+        classname(const char *what) noexcept                                                                                                                   \
             : Akonadi::Server::Exception(what)                                                                                                                 \
         {                                                                                                                                                      \
         }                                                                                                                                                      \
-        classname(const QByteArray &what) throw()                                                                                                              \
+        classname(const QByteArray &what) noexcept                                                                                                             \
             : Akonadi::Server::Exception(what)                                                                                                                 \
         {                                                                                                                                                      \
         }                                                                                                                                                      \
-        classname(const QString &what) throw()                                                                                                                 \
+        classname(const QString &what) noexcept                                                                                                                \
             : Akonadi::Server::Exception(what)                                                                                                                 \
         {                                                                                                                                                      \
         }                                                                                                                                                      \
-        const char *type() const throw() override                                                                                                              \
+        const char *type() const noexcept override                                                                                                             \
         {                                                                                                                                                      \
             return "" #classname;                                                                                                                              \
         }                                                                                                                                                      \
@@ -80,4 +79,3 @@ protected:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
