@@ -3,8 +3,7 @@
  *                                                                         *
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
-#ifndef AKONADI_COLLECTIONCREATEHANDLER_H_
-#define AKONADI_COLLECTIONCREATEHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -27,4 +26,3 @@ public:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
