@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_COLLECTIONMODIFYHANDLER_H_
-#define AKONADI_COLLECTIONMODIFYHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -31,4 +30,3 @@ public:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
