@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEMDELETEHANDLER_H_
-#define AKONADI_ITEMDELETEHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -36,4 +35,3 @@ public:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
