@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ITEMMOVEHANDLER_H_
-#define AKONADI_ITEMMOVEHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -43,4 +42,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
