@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
 
-#ifndef AKONADI_RELATIONFETCHHANDLER_H_
-#define AKONADI_RELATIONFETCHHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -30,4 +29,3 @@ public:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
