@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_RELATIONMODIFYHANDLER_H_
-#define AKONADI_RELATIONMODIFYHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -30,4 +29,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif // AKONADI_RELATIONMODIFYHANDLER_H_
