@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
 
-#ifndef AKONADI_SEARCHHANDLER_H_
-#define AKONADI_SEARCHHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -39,4 +38,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
