@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_TAGMODIFYHANDLER_H_
-#define AKONADI_TAGMODIFYHANDLER_H_
+#pragma once
 
 #include "handler.h"
 
@@ -25,4 +24,3 @@ public:
 } // namespace Server
 } // namespace Akonadi
 
-#endif // AKONADI_TAGMODIFYHANDLER_H_
