@@ -82,7 +82,7 @@ bool PreprocessorManager::isActive()
 
 PreprocessorInstance *PreprocessorManager::lockedFindInstance(const QString &id)
 {
-    for (PreprocessorInstance *instance : qAsConst(mPreprocessorChain)) {
+    for (PreprocessorInstance *instance : std::as_const(mPreprocessorChain)) {
         if (instance->id() == id) {
             return instance;
         }
@@ -265,7 +265,7 @@ void PreprocessorManager::dataStoreDestroyed()
 
     qCDebug(AKONADISERVER_LOG) << "PreprocessorManager::dataStoreDestroyed(): killing the wait queue";
 
-    const auto *dataStore = dynamic_cast<const DataStore *>(sender());
+    const auto dataStore = dynamic_cast<const DataStore *>(sender());
     if (!dataStore) {
         qCWarning(AKONADISERVER_LOG) << "PreprocessorManager::dataStoreDestroyed(): got the signal from a non DataStore object";
         return;
@@ -280,7 +280,7 @@ void PreprocessorManager::dataStoreTransactionCommitted()
 
     qCDebug(AKONADISERVER_LOG) << "PreprocessorManager::dataStoreTransactionCommitted(): pushing items in wait queue to the preprocessing chain";
 
-    const auto *dataStore = dynamic_cast<const DataStore *>(sender());
+    const auto dataStore = dynamic_cast<const DataStore *>(sender());
     if (!dataStore) {
         qCWarning(AKONADISERVER_LOG) << "PreprocessorManager::dataStoreTransactionCommitted(): got the signal from a non DataStore object";
         return;
@@ -312,7 +312,7 @@ void PreprocessorManager::dataStoreTransactionRolledBack()
 
     qCDebug(AKONADISERVER_LOG) << "PreprocessorManager::dataStoreTransactionRolledBack(): killing the wait queue";
 
-    const auto *dataStore = dynamic_cast<const DataStore *>(sender());
+    const auto dataStore = dynamic_cast<const DataStore *>(sender());
     if (!dataStore) {
         qCWarning(AKONADISERVER_LOG) << "PreprocessorManager::dataStoreTransactionCommitted(): got the signal from a non DataStore object";
         return;
@@ -378,7 +378,7 @@ void PreprocessorManager::heartbeat()
 
     QList<PreprocessorInstance *> firedPreprocessors;
 
-    for (PreprocessorInstance *instance : qAsConst(mPreprocessorChain)) {
+    for (PreprocessorInstance *instance : std::as_const(mPreprocessorChain)) {
         // In this loop we check for "stuck" preprocessors.
 
         int elapsedTime = instance->currentProcessingTime();
@@ -428,7 +428,7 @@ void PreprocessorManager::heartbeat()
     }
 
     // Kill the fired preprocessors, if any.
-    for (PreprocessorInstance *instance : qAsConst(firedPreprocessors)) {
+    for (PreprocessorInstance *instance : std::as_const(firedPreprocessors)) {
         lockedUnregisterInstance(instance->id());
     }
 }
