@@ -62,7 +62,7 @@ void SearchManager::init()
     AkThread::init();
 
     mEngines.reserve(mEngineNames.size());
-    for (const QString &engineName : qAsConst(mEngineNames)) {
+    for (const QString &engineName : std::as_const(mEngineNames)) {
         if (engineName == QLatin1String("Agent")) {
             mEngines.append(new AgentSearchEngine);
         } else {
@@ -177,7 +177,7 @@ void SearchManager::loadSearchPlugins()
 
 void SearchManager::initSearchPlugins()
 {
-    for (QPluginLoader *loader : qAsConst(mPluginLoaders)) {
+    for (QPluginLoader *loader : std::as_const(mPluginLoaders)) {
         if (!loader->load()) {
             qCCritical(AKONADISERVER_SEARCH_LOG) << "Failed to load search plugin" << loader->fileName() << ":" << loader->errorString();
             continue;
@@ -199,7 +199,7 @@ void SearchManager::scheduleSearchUpdate()
     // Reset if the timer is active (use QueuedConnection to invoke start() from
     // the thread the QTimer lives in instead of caller's thread, otherwise crashes
     // and weird things can happen.
-    QMetaObject::invokeMethod(mSearchUpdateTimer, QOverload<>::of(&QTimer::start), Qt::QueuedConnection);
+    QMetaObject::invokeMethod(mSearchUpdateTimer, qOverload<>(&QTimer::start), Qt::QueuedConnection);
 }
 
 void SearchManager::searchUpdateTimeout()
@@ -293,7 +293,7 @@ void SearchManager::updateSearchImpl(const Collection &collection)
     }
 
     // Query all plugins for search results
-    const QByteArray id = "searchUpdate-" + QByteArray::number(QDateTime::currentDateTimeUtc().toTime_t());
+    const QByteArray id = "searchUpdate-" + QByteArray::number(QDateTime::currentDateTimeUtc().toSecsSinceEpoch());
     SearchRequest request(id, *this, mAgentSearchManager);
     request.setCollections(queryCollections);
     request.setMimeTypes(queryMimeTypes);
@@ -347,7 +347,7 @@ void SearchManager::updateSearchImpl(const Collection &collection)
 
 void SearchManager::searchUpdateResultsAvailable(const QSet<qint64> &results)
 {
-    const Collection collection = sender()->property("SearchCollection").value<Collection>();
+    const auto collection = sender()->property("SearchCollection").value<Collection>();
     qCDebug(AKONADISERVER_SEARCH_LOG) << "searchUpdateResultsAvailable" << collection.id() << results.count() << "results";
 
     QSet<qint64> newMatches = results;
@@ -382,7 +382,7 @@ void SearchManager::searchUpdateResultsAvailable(const QSet<qint64> &results)
     // This will remove IDs that no longer exist in the DB.
     QVariantList newMatchesVariant;
     newMatchesVariant.reserve(newMatches.count());
-    for (qint64 id : qAsConst(newMatches)) {
+    for (qint64 id : std::as_const(newMatches)) {
         newMatchesVariant << id;
     }
 
