@@ -5,10 +5,8 @@
  *
  */
 
-#ifndef AKONADI_SERVER_COLLECTIONSTATISTICS_H
-#define AKONADI_SERVER_COLLECTIONSTATISTICS_H
+#pragma once
 
-class QMutex;
 
 #include <QHash>
 #include <QMutex>
@@ -64,4 +62,3 @@ protected:
 } // namespace Server
 } // namespace Akonadi
 
-#endif // AKONADI_SERVER_COLLECTIONSTATISTICS_H
