@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: LGPL-2.0-or-later                            *
  ***************************************************************************/
 
-#ifndef DATASTORE_H
-#define DATASTORE_H
+#pragma once
 
 #include <QList>
 #include <QMutex>
@@ -256,7 +255,7 @@ public:
 
     /**
       Commits all changes within the current transaction and emits all
-      collected notfication signals. If committing fails, the transaction
+      collected notification signals. If committing fails, the transaction
       will be rolled back.
     */
     virtual bool commitTransaction();
@@ -370,4 +369,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
