@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_DBDEADLOCKCATCHER_H
-#define AKONADI_DBDEADLOCKCATCHER_H
+#pragma once
 
 #include "dbexception.h"
 
@@ -45,4 +44,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
