@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_DBUPDATER_H
-#define AKONADI_DBUPDATER_H
+#pragma once
 
 #include <QMap>
 #include <QObject>
@@ -25,7 +24,7 @@ namespace Server
 class UpdateSet
 {
 public:
-    typedef QMap<int, UpdateSet> Map;
+    using Map = QMap<int, UpdateSet>;
 
     UpdateSet()
         : version(-1)
@@ -81,4 +80,3 @@ private:
 } // namespace Server
 } // namespace Akonadi
 
-#endif
