@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_QUERY_H
-#define AKONADI_QUERY_H
+#pragma once
 
 #include <QString>
 #include <QVariant>
@@ -26,17 +25,35 @@ namespace Query
 /**
   Compare operators to be used in query conditions.
 */
-enum CompareOperator { Equals, NotEquals, Is, IsNot, Less, LessOrEqual, Greater, GreaterOrEqual, In, NotIn, Like };
+enum CompareOperator {
+    Equals,
+    NotEquals,
+    Is,
+    IsNot,
+    Less,
+    LessOrEqual,
+    Greater,
+    GreaterOrEqual,
+    In,
+    NotIn,
+    Like,
+};
 
 /**
   Logic operations used to combine multiple query conditions.
 */
-enum LogicOperator { And, Or };
+enum LogicOperator {
+    And,
+    Or,
+};
 
 /**
   Sort orders.
 */
-enum SortOrder { Ascending, Descending };
+enum SortOrder {
+    Ascending,
+    Descending,
+};
 
 /**
   Represents a WHERE condition tree.
@@ -47,7 +64,7 @@ class Condition
 
 public:
     /** A list of conditions. */
-    typedef QVector<Condition> List;
+    using List = QVector<Condition>;
 
     /**
       Create an empty condition.
@@ -126,4 +143,3 @@ private:
 
 Q_DECLARE_TYPEINFO(Akonadi::Server::Query::Condition, Q_MOVABLE_TYPE);
 
-#endif
