@@ -184,6 +184,10 @@ template<typename RangeLike, typename Predicate, typename Iterator = typename Ra
 class FilterIterator : public IteratorBase<FilterIterator<RangeLike, Predicate>, RangeLike>
 {
 public:
+    // Filter iterator is just an InputIterator (for complexity reasons).
+    // It actually makes it more efficient with STL algos like std::find()
+    using iterator_category = std::input_iterator_tag;
+
     FilterIterator(const Iterator &iter, const Iterator &end, const Predicate &predicate, const RangeLike &range)
         : IteratorBase<FilterIterator, RangeLike>(iter, range)
         , mPredicate(predicate)
@@ -324,7 +328,7 @@ template<typename UnaryPredicate> struct NoneTag_ {
 } // namespace detail
 } // namespace AkRanges
 
-// Generic operator| for To_<> convertor
+// Generic operator| for To_<> converter
 template<typename RangeLike, template<typename> class OutContainer, typename T = typename RangeLike::value_type>
 auto operator|(const RangeLike &range, AkRanges::detail::ToTag_<OutContainer>) -> OutContainer<T>
 {
@@ -339,7 +343,7 @@ template<template<typename> class InContainer, typename T> auto operator|(const
     return in;
 }
 
-// Generic operator| for ToAssoc_<> convertor
+// Generic operator| for ToAssoc_<> converter
 template<typename RangeLike, template<typename, typename> class OutContainer, typename T = typename RangeLike::value_type>
 auto operator|(const RangeLike &range, AkRanges::detail::ToAssocTag_<OutContainer>) -> OutContainer<typename T::first_type, typename T::second_type>
 {
