@@ -51,7 +51,7 @@ public:
         mOldHandler = qInstallMessageHandler(dbusLogger);
     }
 
-    ~RemoteLogger()
+    ~RemoteLogger() override
     {
         sInstance = nullptr;
 
@@ -79,8 +79,8 @@ private Q_SLOTS:
             return;
         }
 
-        connect(mAkonadiConsoleInterface.get(),
-                SIGNAL(enabledChanged(bool)), // clazy:exclude=old-style-connect
+        connect(mAkonadiConsoleInterface.get(), // clazy:exclude=old-style-connect
+                SIGNAL(enabledChanged(bool)),
                 this,
                 SLOT(onAkonadiConsoleLoggingEnabled(bool)));
 
@@ -136,7 +136,7 @@ private:
 
     static void categoryFilter(QLoggingCategory *cat)
     {
-        auto *const that = self();
+        auto const that = self();
         if (!that) {
             return;
         }
@@ -153,7 +153,7 @@ private:
 
     static void dbusLogger(QtMsgType type, const QMessageLogContext &ctx, const QString &msg)
     {
-        auto *const that = self();
+        auto const that = self();
         if (!that) {
             return;
         }
