@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ACTIONSTATEMANAGER_P_H
-#define AKONADI_ACTIONSTATEMANAGER_P_H
+#pragma once
 
 #include "collection.h"
 #include "item.h"
@@ -69,4 +68,3 @@ private:
 
 }
 
-#endif
