@@ -41,10 +41,10 @@ static_assert(numAgentActionData == AgentActionManager::LastType, "agentActionDa
 /**
  * @internal
  */
-class Q_DECL_HIDDEN AgentActionManager::Private
+class Akonadi::AgentActionManagerPrivate
 {
 public:
-    explicit Private(AgentActionManager *parent)
+    explicit AgentActionManagerPrivate(AgentActionManager *parent)
         : q(parent)
     {
         mActions.fill(nullptr, AgentActionManager::LastType);
@@ -90,9 +90,9 @@ public:
             }
         }
 
-        enableAction(CreateAgentInstance, createActionEnabled);
-        enableAction(DeleteAgentInstance, deleteActionEnabled);
-        enableAction(ConfigureAgentInstance, configureActionEnabled);
+        enableAction(AgentActionManager::CreateAgentInstance, createActionEnabled);
+        enableAction(AgentActionManager::DeleteAgentInstance, deleteActionEnabled);
+        enableAction(AgentActionManager::ConfigureAgentInstance, configureActionEnabled);
 
         Q_EMIT q->actionStateUpdated();
     }
@@ -107,7 +107,7 @@ public:
 
         const QModelIndexList lstModelIndex = mSelectionModel->selectedRows();
         for (const QModelIndex &index : lstModelIndex) {
-            const AgentInstance instance = index.data(AgentInstanceModel::InstanceRole).value<AgentInstance>();
+            const auto instance = index.data(AgentInstanceModel::InstanceRole).value<AgentInstance>();
             if (instance.isValid()) {
                 instances << instance;
             }
@@ -121,11 +121,11 @@ public:
         QPointer<Akonadi::AgentTypeDialog> dlg(new Akonadi::AgentTypeDialog(mParentWidget));
         dlg->setWindowTitle(contextText(AgentActionManager::CreateAgentInstance, AgentActionManager::DialogTitle));
 
-        for (const QString &mimeType : qAsConst(mMimeTypeFilter)) {
+        for (const QString &mimeType : std::as_const(mMimeTypeFilter)) {
             dlg->agentFilterProxyModel()->addMimeTypeFilter(mimeType);
         }
 
-        for (const QString &capability : qAsConst(mCapabilityFilter)) {
+        for (const QString &capability : std::as_const(mCapabilityFilter)) {
             dlg->agentFilterProxyModel()->addCapabilityFilter(capability);
         }
 
@@ -205,7 +205,7 @@ public:
     QStringList mMimeTypeFilter;
     QStringList mCapabilityFilter;
 
-    typedef QHash<AgentActionManager::TextContext, QString> ContextTexts;
+    using ContextTexts = QHash<AgentActionManager::TextContext, QString>;
     QHash<AgentActionManager::Type, ContextTexts> mContextTexts;
 };
 
@@ -213,16 +213,13 @@ public:
 
 AgentActionManager::AgentActionManager(KActionCollection *actionCollection, QWidget *parent)
     : QObject(parent)
-    , d(new Private(this))
+    , d(new AgentActionManagerPrivate(this))
 {
     d->mParentWidget = parent;
     d->mActionCollection = actionCollection;
 }
 
-AgentActionManager::~AgentActionManager()
-{
-    delete d;
-}
+AgentActionManager::~AgentActionManager() = default;
 
 void AgentActionManager::setSelectionModel(QItemSelectionModel *selectionModel)
 {
@@ -273,7 +270,7 @@ QAction *AgentActionManager::createAction(Type type)
 void AgentActionManager::createAllActions()
 {
     for (int type = 0; type < LastType; ++type) {
-        auto *action = createAction(static_cast<Type>(type));
+        auto action = createAction(static_cast<Type>(type));
         Q_UNUSED(action)
     }
 }
