@@ -4,14 +4,16 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_AGENTACTIONMANAGER_H
-#define AKONADI_AGENTACTIONMANAGER_H
+#pragma once
 
 #include "akonadiwidgets_export.h"
-#include "agentinstance.h"
+// AkonadiCore
+#include <akonadi/agentinstance.h>
 
 #include <QObject>
 
+#include <memory>
+
 class QAction;
 class KActionCollection;
 class KLocalizedString;
@@ -20,6 +22,7 @@ class QWidget;
 
 namespace Akonadi
 {
+class AgentActionManagerPrivate;
 
 /**
  * @short Manages generic actions for agent and agent instance views.
@@ -35,23 +38,23 @@ public:
      * Describes the supported actions.
      */
     enum Type {
-        CreateAgentInstance,       ///< Creates an agent instance
-        DeleteAgentInstance,       ///< Deletes the selected agent instance
-        ConfigureAgentInstance,    ///< Configures the selected agent instance
-        LastType                   ///< Marks last action
+        CreateAgentInstance, ///< Creates an agent instance
+        DeleteAgentInstance, ///< Deletes the selected agent instance
+        ConfigureAgentInstance, ///< Configures the selected agent instance
+        LastType ///< Marks last action
     };
 
     /**
      * Describes the text context that can be customized.
      */
     enum TextContext {
-        DialogTitle,                ///< The window title of a dialog
-        DialogText,                 ///< The text of a dialog
-        MessageBoxTitle,            ///< The window title of a message box
-        MessageBoxText,             ///< The text of a message box
-        MessageBoxAlternativeText,  ///< An alternative text of a message box
-        ErrorMessageTitle,          ///< The window title of an error message
-        ErrorMessageText            ///< The text of an error message
+        DialogTitle, ///< The window title of a dialog
+        DialogText, ///< The text of a dialog
+        MessageBoxTitle, ///< The window title of a message box
+        MessageBoxText, ///< The text of a message box
+        MessageBoxAlternativeText, ///< An alternative text of a message box
+        ErrorMessageTitle, ///< The window title of an error message
+        ErrorMessageText ///< The text of an error message
     };
 
     /**
@@ -65,7 +68,7 @@ public:
     /**
      * Destroys the agent action manager.
      */
-    ~AgentActionManager();
+    ~AgentActionManager() override;
 
     /**
      * Sets the agent selection @p model based on which the actions should operate.
@@ -152,9 +155,8 @@ Q_SIGNALS:
     void actionStateUpdated();
 
 private:
-    //@cond PRIVATE
-    class Private;
-    Private *const d;
+    /// @cond PRIVATE
+    std::unique_ptr<AgentActionManagerPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void updateActions())
 
@@ -163,9 +165,8 @@ private:
     Q_PRIVATE_SLOT(d, void slotConfigureAgentInstance())
 
     Q_PRIVATE_SLOT(d, void slotAgentInstanceCreationResult(KJob *))
-    //@endcond
+    /// @endcond
 };
 
 }
 
-#endif
