@@ -25,10 +25,10 @@
 
 using namespace Akonadi;
 
-class CollectionMaintenancePage::Private
+class Akonadi::CollectionMaintenancePagePrivate
 {
 public:
-    Private()
+    CollectionMaintenancePagePrivate()
     {
     }
 
@@ -64,16 +64,13 @@ public:
 
 CollectionMaintenancePage::CollectionMaintenancePage(QWidget *parent)
     : CollectionPropertiesPage(parent)
-    , d(new Private)
+    , d(new CollectionMaintenancePagePrivate)
 {
     setObjectName(QStringLiteral("Akonadi::CollectionMaintenancePage"));
     setPageTitle(i18n("Maintenance"));
 }
 
-CollectionMaintenancePage::~CollectionMaintenancePage()
-{
-    delete d;
-}
+CollectionMaintenancePage::~CollectionMaintenancePage() = default;
 
 void CollectionMaintenancePage::init(const Collection &col)
 {
@@ -93,7 +90,7 @@ void CollectionMaintenancePage::init(const Collection &col)
         d->ui.folderTypeLbl->setText(instance.type().name());
     } else {
         d->ui.folderTypeLbl->hide();
-        d->ui.filesLayout->labelForField(d->ui.folderTypeLbl)->hide();
+        d->ui.verticalLayout->labelForField(d->ui.folderTypeLbl)->hide();
     }
 
     connect(d->ui.reindexButton, &QPushButton::clicked, this, [this]() {
@@ -105,7 +102,10 @@ void CollectionMaintenancePage::init(const Collection &col)
     const auto resource = Akonadi::AgentManager::self()->instance(col.resource()).type();
     if (!col.cachePolicy().localParts().contains(QLatin1String("RFC822"))
         && resource.customProperties().value(QStringLiteral("HasLocalStorage"), QString()) != QLatin1String("true")) {
-        d->ui.indexingGroup->hide();
+        d->ui.indexingLabel->hide();
+        d->ui.enableIndexingChkBox->hide();
+        d->ui.indexedCountLbl->hide();
+        d->ui.reindexButton->hide();
     }
 }
 
@@ -114,7 +114,7 @@ void CollectionMaintenancePage::load(const Collection &col)
     init(col);
     if (col.isValid()) {
         d->updateLabel(col.statistics().count(), col.statistics().unreadCount(), col.statistics().size());
-        const auto *attr = col.attribute<Akonadi::IndexPolicyAttribute>();
+        const auto attr = col.attribute<Akonadi::IndexPolicyAttribute>();
         const bool indexingWasEnabled(!attr || attr->indexingEnabled());
         d->ui.enableIndexingChkBox->setChecked(indexingWasEnabled);
         if (indexingWasEnabled) {
@@ -150,6 +150,6 @@ void CollectionMaintenancePage::save(Collection &collection)
         return;
     }
 
-    auto *attr = collection.attribute<Akonadi::IndexPolicyAttribute>(Akonadi::Collection::AddIfMissing);
+    auto attr = collection.attribute<Akonadi::IndexPolicyAttribute>(Akonadi::Collection::AddIfMissing);
     attr->setIndexingEnabled(d->ui.enableIndexingChkBox->isChecked());
 }
