@@ -6,13 +6,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ENTITYLISTVIEW_H
-#define AKONADI_ENTITYLISTVIEW_H
+#pragma once
 
 #include "akonadiwidgets_export.h"
 
 #include <QListView>
 
+#include <memory>
+
 class KXMLGUIClient;
 class QDragMoveEvent;
 
@@ -20,6 +21,7 @@ namespace Akonadi
 {
 class Collection;
 class Item;
+class EntityListViewPrivate;
 
 /**
  * @short A view to show an item/collection list provided by an EntityTreeModel.
@@ -185,11 +187,9 @@ protected:
 
 private:
     /// @cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<EntityListViewPrivate> const d;
     /// @endcond
 };
 
 }
 
-#endif
