@@ -6,13 +6,13 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ETMVIEWSTATESAVER_H
-#define AKONADI_ETMVIEWSTATESAVER_H
+#pragma once
 
 #include <KConfigViewStateSaver>
 
-#include "collection.h"
-#include "item.h"
+// AkonadiCore
+#include <akonadi/collection.h>
+#include <akonadi/item.h>
 
 #include "akonadiwidgets_export.h"
 
@@ -40,4 +40,3 @@ protected:
 
 }
 
-#endif
