@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,14 +18,14 @@ RenameFavoriteDialog::RenameFavoriteDialog(const QString &value, const QString &
 {
     ui.setupUi(this);
 
-    connect(ui.lineEdit, &QLineEdit::textChanged,
-            this, [this](const QString &text) {
-                ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!text.trimmed().isEmpty());
-            });
+    connect(ui.lineEdit, &QLineEdit::textChanged, this, [this](const QString &text) {
+        ui.buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!text.trimmed().isEmpty());
+    });
     connect(ui.buttonBox, &QDialogButtonBox::accepted, this, &RenameFavoriteDialog::accept);
     connect(ui.buttonBox, &QDialogButtonBox::rejected, this, &RenameFavoriteDialog::reject);
-    connect(ui.buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked,
-            this, [this]() { ui.lineEdit->setText(m_defaultName); });
+    connect(ui.buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, [this]() {
+        ui.lineEdit->setText(m_defaultName);
+    });
 
     ui.lineEdit->setText(value);
 }
