@@ -45,7 +45,14 @@ static QString makeLink(const QString &file)
     return QStringLiteral("<a href=\"%1\">%2</a>").arg(file, file);
 }
 
-enum SelfTestRole { ResultTypeRole = Qt::UserRole, FileIncludeRole, ListDirectoryRole, EnvVarRole, SummaryRole, DetailsRole };
+enum SelfTestRole {
+    ResultTypeRole = Qt::UserRole,
+    FileIncludeRole,
+    ListDirectoryRole,
+    EnvVarRole,
+    SummaryRole,
+    DetailsRole,
+};
 
 SelfTestDialog::SelfTestDialog(QWidget *parent)
     : QDialog(parent)
@@ -86,7 +93,7 @@ void SelfTestDialog::hideIntroduction()
 
 QStandardItem *SelfTestDialog::report(ResultType type, const KLocalizedString &summary, const KLocalizedString &details)
 {
-    QStandardItem *item = new QStandardItem(summary.toString());
+    auto item = new QStandardItem(summary.toString());
     switch (type) {
     case Skip:
         item->setIcon(QIcon::fromTheme(QStringLiteral("dialog-ok")));
