@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SELFTESTDIALOG_P_H
-#define AKONADI_SELFTESTDIALOG_P_H
+#pragma once
 
 #include "akonadiwidgets_export.h"
 #include "ui_selftestdialog.h"
@@ -49,7 +48,12 @@ private Q_SLOTS:
     void runTests();
 
 private:
-    enum ResultType { Skip, Success, Warning, Error };
+    enum ResultType {
+        Skip,
+        Success,
+        Warning,
+        Error,
+    };
     QStandardItem *report(ResultType type, const KLocalizedString &summary, const KLocalizedString &details);
     QVariant serverSetting(const QString &group, const char *key, const QVariant &def) const;
     bool useStandaloneMysqlServer() const;
@@ -74,4 +78,3 @@ private:
     QStandardItemModel *mTestModel = nullptr;
 };
 }
-#endif
