@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-only
 */
 
-#ifndef COLLECTIONTEST_H
-#define COLLECTIONTEST_H
+#pragma once
 
 #include "collection.h"
 #include <QObject>
@@ -20,4 +19,3 @@ private Q_SLOTS:
     void testBuildCollection();
 };
 
-#endif
