@@ -10,18 +10,18 @@
 
 #include "item.h"
 
+#include <QApplication>
 #include <QDebug>
 #include <QFile>
-#include <QApplication>
 
 #include <KLocalizedString>
 
 #include <KAboutData>
-#include <QCommandLineParser>
 #include <QCommandLineOption>
+#include <QCommandLineParser>
 
-#include "transactionjobs.h"
 #include "itemcreatejob.h"
+#include "transactionjobs.h"
 
 #define GLOBAL_TRANSACTION 1
 
@@ -30,7 +30,7 @@ using namespace Akonadi;
 ItemDumper::ItemDumper(const QString &path, const QString &filename, const QString &mimetype, int count)
     : mJobCount(0)
 {
-    CollectionPathResolver *resolver = new CollectionPathResolver(path, this);
+    auto resolver = new CollectionPathResolver(path, this);
     Q_ASSERT(resolver->exec());
     const Collection collection = Collection(resolver->collection());
 
@@ -43,17 +43,17 @@ ItemDumper::ItemDumper(const QString &path, const QString &filename, const QStri
     item.setPayloadFromData(data);
     mTime.start();
 #ifdef GLOBAL_TRANSACTION
-    TransactionBeginJob *begin = new TransactionBeginJob(this);
+    auto begin = new TransactionBeginJob(this);
     connect(begin, &TransactionBeginJob::result, this, &ItemDumper::done);
     ++mJobCount;
 #endif
     for (int i = 0; i < count; ++i) {
         ++mJobCount;
-        ItemCreateJob *job = new ItemCreateJob(item, collection, this);
+        auto job = new ItemCreateJob(item, collection, this);
         connect(job, &ItemCreateJob::result, this, &ItemDumper::done);
     }
 #ifdef GLOBAL_TRANSACTION
-    TransactionCommitJob *commit = new TransactionCommitJob(this);
+    auto commit = new TransactionCommitJob(this);
     connect(commit, &TransactionCommitJob::result, this, &ItemDumper::done);
     ++mJobCount;
 #endif
@@ -74,16 +74,20 @@ void ItemDumper::done(KJob *job)
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("test"),
-                         i18n("Test Application"),
-                         QStringLiteral("1.0"));
+    KAboutData aboutData(QStringLiteral("test"), i18n("Test Application"), QStringLiteral("1.0"));
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("path"), i18n("IMAP destination path"), QStringLiteral("argument")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("mimetype"), i18n("Source mimetype"), QStringLiteral("argument"), QStringLiteral("application/octet-stream")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("mimetype"),
+                                        i18n("Source mimetype"),
+                                        QStringLiteral("argument"),
+                                        QStringLiteral("application/octet-stream")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("file"), i18n("Source file"), QStringLiteral("argument")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("count"), i18n("Number of times this file is added"), QStringLiteral("argument"), QStringLiteral("1")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("count"),
+                                        i18n("Number of times this file is added"),
+                                        QStringLiteral("argument"),
+                                        QStringLiteral("1")));
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
